upgrade-requirements.py Changelog
---------------------------------


#### Version 1.6.0 (2018-06-13)

- Enhancement: Handle spaces around requirements package names ([#4](https://github.com/joeyespo/grip/pull/4) - thanks, [@ldsink][]!)


#### Version 1.5.0 (2017-08-27)

- Enhancement: Handle comments in requirements file ([#2](https://github.com/joeyespo/grip/pull/2) - thanks, [@emilecaron][]!)


#### Version 1.4.0 (2017-04-15)

- Enhancement: Python 3 support
- Bugfix: Fix potential Unicode errors in `pip show` output


#### Version 1.3.0 (2017-04-15)

- Initial commit of working project


[@emilecaron]: https://github.com/emilecaron
[@ldsink]: https://github.com/ldsink
